==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>모든 글꼴</translation>
    </message>
    <message>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <source>User</source>
        <translation>사용자</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>활성</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>중국어</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>고정폭</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>사용가능</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>사용안함</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>깨진 파일</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>동일한 버전 설치됨</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>시스템 글꼴</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>페이지 위로</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>페이지 아래로</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1개 글꼴 설치됨</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1개 글꼴 설치됨</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1개의 글꼴을 설치하지 못했습니다. 디스크 공간이 부족합니다.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">깨진 파일</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>이 글꼴은 응용프로그램에서 사용할 수 없습니다</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>이러한 글꼴은 응용프로그램에서 사용할 수 없습니다</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>다른 %1 시스템 글꼴은 삭제할 수 없습니다</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>사용 중인 &quot;%1&quot; 글꼴은 삭제할 수 없습니다</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>사용 중인 다른 %1 시스템 글꼴과 &quot;%2&quot; 글꼴은 삭제할 수 없습니다</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1개의 글꼴을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>글꼴 삭제중, 기다려 주십시오...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>글꼴 확인</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>설치할 폰트가 없습니다</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">종료</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">계속</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>기본 정보</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>스타일</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>유형</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>버전</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>전체 이름</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps 이름</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>트레이드마크</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>글꼴 관리자</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>글꼴 관리자는 사용자가 글꼴을 설치하고 관리하는 데 도움이 됩니다.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>글꼴 불러오는 중, 기다려 주십시오...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>바탕화면으로 내보낸 글꼴</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>바탕화면으로 내보낸 글꼴 %1개</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1개의 글꼴을 내보내지 못했습니다. 디스크 공간이 부족합니다.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1개의 글꼴을 내보내지 못했습니다. 디스크 공간이 부족합니다.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>글꼴 추가</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>사용가능</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>사용안함</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>상세 정보</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리자에 표시</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>비활성화됨</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>글꼴이 비활성화됨</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1이(가) 사용중이므로 사용하지 않도록 설정할 수 없습니다</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>시스템 글꼴 및 사용중인 글꼴을 비활성화 할 수 없습니다</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>시스템 글꼴을 비활성화 할 수 없습니다</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>글꼴 설치</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>확인중...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>깨진 파일</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>설치됨</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>설치되지 않음</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>글꼴 설치</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>검색 결과 없음</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>글꼴 없음</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>페이지 위로</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>페이지 아래로</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>글꼴 추가</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>글꼴 정보</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>미리보기 텍스트 입력</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>모든 글꼴</translation>
    </message>
    <message>
        <source>System</source>
        <translation>시스템</translation>
    </message>
    <message>
        <source>User</source>
        <translation>사용자</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>활성</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>중국어</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>고정폭</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>사용가능</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>사용안함</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>깨진 파일</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>동일한 버전 설치됨</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>시스템 글꼴</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>페이지 위로</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>페이지 아래로</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1개 글꼴 설치됨</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1개 글꼴 설치됨</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1개의 글꼴을 설치하지 못했습니다. 디스크 공간이 부족합니다.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>글꼴</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>깨진 파일</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>이 글꼴은 응용프로그램에서 사용할 수 없습니다</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>이러한 글꼴은 응용프로그램에서 사용할 수 없습니다</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>다른 %1 시스템 글꼴은 삭제할 수 없습니다</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>사용 중인 &quot;%1&quot; 글꼴은 삭제할 수 없습니다</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>사용 중인 다른 %1 시스템 글꼴과 &quot;%2&quot; 글꼴은 삭제할 수 없습니다</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1개의 글꼴을 삭제하시겠습니까?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>글꼴 삭제중, 기다려 주십시오...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>글꼴 확인</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>설치할 폰트가 없습니다</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>계속</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>당신의 꿈을 꿈으로 만들지 마십시오</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>기본 정보</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>스타일</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>유형</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>버전</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>설명</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>전체 이름</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps 이름</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>트레이드마크</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>글꼴 관리자</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>글꼴 관리자는 사용자가 글꼴을 설치하고 관리하는 데 도움이 됩니다.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>글꼴 불러오는 중, 기다려 주십시오...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>바탕화면으로 내보낸 글꼴</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>바탕화면으로 내보낸 글꼴 %1개</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1개의 글꼴을 내보내지 못했습니다. 디스크 공간이 부족합니다.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1개의 글꼴을 내보내지 못했습니다. 디스크 공간이 부족합니다.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>글꼴 추가</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>사용가능</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>사용안함</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>상세 정보</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리자에 표시</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>비활성화됨</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>글꼴이 비활성화됨</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1이(가) 사용중이므로 사용하지 않도록 설정할 수 없습니다</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>시스템 글꼴 및 사용중인 글꼴을 비활성화 할 수 없습니다</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>시스템 글꼴을 비활성화 할 수 없습니다</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>글꼴 설치</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>확인중...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>깨진 파일</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>설치됨</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>설치되지 않음</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>글꼴 설치</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>검색 결과 없음</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>글꼴 없음</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>페이지 위로</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>페이지 아래로</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>글꼴 추가</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>글꼴 정보</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>미리보기 텍스트 입력</translation>
    </message>
</context>
</TS>
